#
# spec file for package kubectl-view-secret
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

# to be recognized as a kubectl plugin,
# there must not be a hyphen in the plugin name
%define executable_name kubectl-view_secret

Name:           kubectl-view-secret
Version:        0.13.0
Release:        1.4
Summary:        Kubernetes CLI plugin to decode Kubernetes secrets
License:        MIT
URL:            https://github.com/elsesiy/kubectl-view-secret
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
This plugin allows for easy secret decoding. Useful if you want to see what's inside of a secret without always go through the following:

* kubectl get secret <secret> -o yaml
* Copy base64 encoded secret
* echo "b64string" | base64 -d

%prep
%autosetup -p1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -o bin/%{name} ./cmd/kubectl-view-secret.go

ls -lh

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}
cd %{buildroot}/%{_bindir}/
ln -s %{name} %{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{executable_name}

%changelog
* Fri Aug 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.13.0:
  * Update changelog for v0.13.0 release
  * Integrate with huh for better interface (#47)
  * Add instructions for nixpkgs to README (#49)
  * Add test coverage via codecov.io (#48)
* Fri Aug  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- make kubectl recognize this as a plugin by having an executable
  with the right name
* Fri Aug  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.12.1:
  * Update changelog for v0.12.1 release
  * Misc chores (#46)
  * Ease copy past of install command (#45)
  * Issue-42 Adding support for impersonating groups with flag
  - -as-group (#43)
* Mon Feb 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.12.0:
  * Update changelog for v0.12.0 release
  * Update go toolchain to 1.22, bump dependencies (#41)
  * Add support for impersonating a user or service account with
    flag (#39)
  * Update changelog for v0.11.0 release
- BuildRequire go1.22 following upstream
* Fri Nov 10 2023 Johannes Kastl <kastl@b1-systems.de>
- Kubernetes CLI plugin to decode Kubernetes secrets
